package organizer.components;

import nextapp.echo2.app.ApplicationInstance;
import nextapp.echo2.app.Button;
import nextapp.echo2.app.CheckBox;
import nextapp.echo2.app.Extent;
import nextapp.echo2.app.Grid;
import nextapp.echo2.app.Label;
import nextapp.echo2.app.RadioButton;
import nextapp.echo2.app.Row;
import nextapp.echo2.app.SelectField;
import nextapp.echo2.app.SplitPane;
import nextapp.echo2.app.TextArea;
import nextapp.echo2.app.TextField;
import nextapp.echo2.app.WindowPane;
import nextapp.echo2.app.button.ButtonGroup;
import nextapp.echo2.app.event.ActionEvent;
import nextapp.echo2.app.event.ActionListener;
import nextapp.echo2.extras.app.TabPane;
import nextapp.echo2.extras.app.layout.TabPaneLayoutData;

import organizer.AppInstance;
import organizer.images.Images;
import organizer.messages.Messages;

import echopointng.KeyStrokeListener;

/**
 * Trieda AddWindow predstavuje okno pomocou, ktor vkladme do programu lohu.
 */
public class AddWindow  extends WindowPane
{
	/** Id tlaidiel pre zobrazenie kalendra. */
	public static final String START_DATE_BUTTON_ID = "startDateButton";
	public static final String END_DATE_BUTTON_ID = "endDateButton";
	public static final String MEETING_TAB_BUTTON = "meetingTab";
	public static final String TASK_TAB_BUTTON = "taskTab";
	private TextField startField;
	private TextField endField;
	private TextField subjectField;
	private TextField placeField;
	private TextArea notesArea;
	private TextField nameField;
	private RadioButton workingStateButton;
	private RadioButton preparationStateButton;
	private SelectField priorityField;
	private CheckBox alarmField;
	private Button submitButton;
	private KeyStrokeListener keyStroke;
	
	/**
	 * Bezparametrick kontruktor triedy AddWindow. V kontruktore nastavme zkladn
	 * vlastnosti okna. Vetko nastavujeme pomocou tlom okrem vekosti, lebo t sa 
	 * z okna na okno me zmeni. Oknu nastavujeme rune aj jeho modalnos. Modlnos
	 * znamen, e okno preberie ,,kontrolu" nad aplikcia take pokia je otvoren nie je
	 * mon klikn inde. Modlnos nie je mone nastavi cez tly.
	 * Po nastaven vlastnost okna pridme zloky.
	 * 
	 */
	public AddWindow()
	{
		// Vekost okna zadvame dynamicky. 
		setWidth(new Extent(600));
		setHeight(new Extent(400));
		setStyleName("Window");
		setModal(true);
		

		keyStroke = new KeyStrokeListener();
		keyStroke.addKeyCombination(KeyStrokeListener.VK_RETURN, "Enter");
		keyStroke.addKeyCombination(KeyStrokeListener.VK_ESCAPE, "Escape");
		keyStroke.addActionListener(new ActionListener() 
		{
			public void actionPerformed(ActionEvent ae) 
			{
				if(ae.getActionCommand() == "Enter")
				{
					submitButton.fireActionPerformed(ae);
				}
				if(ae.getActionCommand() == "Escape")
				{
					 ApplicationInstance.getActive().getDefaultWindow().getContent().remove(AddWindow.this);
				}
			}
		});
		// Vytvorme zloky
		TabPane pane = new TabPane();
		pane.setStyleName("AddWindowPane");
		pane.add(createMeetingTab());
		
		
		pane.add(createTaskTab());
		add(pane);
		
	     
	}
	
	/**
	 * Metda vytvra zloku pre stretnutie. Zloke nastavme nadpis pomocou triedy
	 * TabPaneLayoutData a jej metdy setTitle. Nsledne vytvorme jednotliv komponenty,
	 * tie pridme do objektu triedy Grid. Trieda Grid m samovysvetlujci nzov - je to 
	 * jednoducho mrieka. Do tejto mrieky postupne pridvame komponenty.
	 * Tto mrieku spolu s odosielacm tlaidlom vlome do objektu SplitPane, ktor metda
	 * vrti. 
	 * 
	 * @return Objekt triedy SplitPane naplnen potrebnmi komponentami.
	 */
	public SplitPane createMeetingTab()
	{
		// Vytvorme SplitPane
		SplitPane meetingPane = new SplitPane(SplitPane.ORIENTATION_VERTICAL_BOTTOM_TOP,new Extent(30));
		// Objektom layout nastavme nzov zloky.
		TabPaneLayoutData layout = new TabPaneLayoutData();
		layout.setTitle(Messages.getMessage("AddWindow.Meeting"));
		meetingPane.setLayoutData(layout);
		/*==========================VYTVRANIE KOMPONENTOV==========================*/
		// Mrieka, do ktorej sa pridaj vektky komponenty
		Grid grid = new Grid();
		grid.setStyleName("Grid");
		// TextField pre predmet
		subjectField = new TextField();
		subjectField.setStyleName("InputField");
		// TextField pre miesto
		placeField = new TextField();
		placeField.setStyleName("InputField");
		// TextField pre zaiaton dtum
		startField = new TextField();
		startField.setStyleName("InputField");
		// TextField pre koneny dtum
		endField = new TextField();
		endField.setStyleName("InputField");
		// TextArea pre poznmky
		notesArea = new TextArea();
		notesArea.setStyleName("TextArea");
		// Label pre predmet		
		Label subjectLabel = new Label(Messages.getMessage("MeetingTab.Subject"));
		subjectLabel.setStyleName("InputLabel");
		// Label pre miesto
		Label placeLabel = new Label(Messages.getMessage("MeetingTab.Place"));
		placeLabel.setStyleName("InputLabel");
		// Label pre zaiaton dtum
		Label startLabel = new Label(Messages.getMessage("MeetingTab.Start"));
		startLabel.setStyleName("InputLabel");
		// Label pre koneny dtum
		Label endLabel = new Label(Messages.getMessage("MeetingTab.End"));
		endLabel.setStyleName("InputLabel");
		// Label pre poznmky
		Label noteLabel = new Label(Messages.getMessage("MeetingTab.Note"));
		noteLabel.setStyleName("InputLabel");
		// Odosielacie tlaidlo
		submitButton = new Button();
		submitButton.setIcon(Images.SUBMIT_BUTTON);
		submitButton.setId(MEETING_TAB_BUTTON);
		// Riadok pre odosielacie tlaidlo
		Row buttonRow = new Row();
		buttonRow.setStyleName("SubmitButtonRow");
		buttonRow.add(keyStroke);
		/*==========================PRIDVANIE KOMPONENTOV==========================*/
		// Riadok pre odosielacie tlaidlo
		buttonRow.add(submitButton);
		// Komponenty pridme do mrieky	
		// 1. Riadok
		grid.add(subjectLabel);
		grid.add(subjectField);
		// 2. Riadok
		grid.add(placeLabel);
		grid.add(placeField);
		// 3. Riadok
		grid.add(startLabel);
		grid.add(startField);
		// 4. Riadok
		grid.add(endLabel);
		grid.add(endField);
		// 5. Riadok
		grid.add(noteLabel);
		grid.add(notesArea);
		// Do objektu SplitPane vlome najrpv riadok s tlaidlom a potom mrieku
		meetingPane.add(buttonRow);
		meetingPane.add(grid);
		
		return meetingPane;
	}
	
	/**
	 * Metda vytvra formulr pre zadvanie lohy do systmu. Postupne vytvra jednotliv komponenty 
	 * a pridva ich do mrieky. 
	 * */
	public SplitPane createTaskTab()
	{
		// Vytvorme SplitPane
		SplitPane meetingPane = new SplitPane(SplitPane.ORIENTATION_VERTICAL_BOTTOM_TOP,new Extent(30));
		// Objektom layout nastavme nzov zloky.
		TabPaneLayoutData layout = new TabPaneLayoutData();
		layout.setTitle(Messages.getMessage("AddWindow.Task"));
		meetingPane.setLayoutData(layout);
		/*==========================VYTVRANIE KOMPONENTOV==========================*/
		// Mrieka, do ktorej sa pridaj vektky komponenty
		Grid grid = new Grid(2);
		grid.setStyleName("Grid");
		// TextField pre nazov
		nameField = new TextField();
		nameField.setStyleName("InputField");
		// Skupina pre radio buttony
		ButtonGroup buttonGroup = new ButtonGroup();
		// RadioButton pre ulohu, ktora sa pripravuje na riesenie
		preparationStateButton = new RadioButton();
		preparationStateButton.setGroup(buttonGroup);
		// RadioButton pre uloha, ktora sa prave riesi
		workingStateButton = new RadioButton();
		workingStateButton.setGroup(buttonGroup);
		// SelectField pre prioritu
		priorityField = createPriorityField();
		// CheckBox pre alarm
		alarmField = new CheckBox();
		// TextField pre zaiaton dtum
		startField = new TextField();
		startField.setStyleName("InputField");
		// TextField pre koneny dtum
		endField = new TextField();
		endField.setStyleName("InputField");
		// TextArea pre text ku lohe
		TextArea taskArea = new TextArea();
		taskArea.setStyleName("TextArea");
		// Label pre predmet		
		Label nameLabel = new Label(Messages.getMessage("TaskTab.Name"));
		nameLabel.setStyleName("InputLabel");
		// Label pre ulohu, ktora sa pripravuje na riesenie
		Label preparationLabel = new Label(Messages.getMessage("TaskTab.State.Preparation"));
		preparationLabel.setStyleName("InputLabel");
		// Label pre ulohu, ktora sa prave riesi
		Label workingLabel = new Label(Messages.getMessage("TaskTab.State.Working"));
		workingLabel.setStyleName("InputLabel");
		// Label pre prioritu ulohy
		Label priorityLabel = new Label(Messages.getMessage("TaskTab.Priority"));
		priorityLabel.setStyleName("InputLabel");
		// Label pre alarm
		Label alarmLabel = new Label(Messages.getMessage("TaskTab.Alarm"));
		alarmLabel.setStyleName("InputLabel");
		// Label pre zaiaton dtum
		Label startLabel = new Label(Messages.getMessage("TaskTab.Start"));
		startLabel.setStyleName("InputLabel");
		// Label pre koneny dtum
		Label endLabel = new Label(Messages.getMessage("TaskTab.End"));
		endLabel.setStyleName("InputLabel");
		// Label pre zadanie lohy
		Label taskLabel = new Label(Messages.getMessage("TaskTab.TaskText"));
		taskLabel.setStyleName("InputLabel");
		// Tlaidlo pre kalendr, pre zaiaton dtum
		Button startDateButton = new Button();
		startDateButton.setIcon(Images.CALLENDAR_WINDOW_BUTTON);
		startDateButton.setId(START_DATE_BUTTON_ID);
		startDateButton.addActionListener(calendarListener);
		// Tlaidlo pre kalendr, pre konen dtum
		Button endDateButton = new Button();
		endDateButton.setIcon(Images.CALLENDAR_WINDOW_BUTTON);
		endDateButton.setId(END_DATE_BUTTON_ID);
		endDateButton.addActionListener(calendarListener);
		// Odosielacie tlaidlo
	    submitButton = new Button();
		submitButton.setIcon(Images.SUBMIT_BUTTON);
		// Riadok pre obalenie startField a startDateButton
		Row startDateRow = new Row();
		//Riadok pre obalenie endField a endDateButton
		Row endDateRow = new Row();
		// Riadok pre obalenie radiobutton pre prvy typ ulohy
		Row preparationRow = new Row();
		// Riadok pre obalenie radiobutton pre druhy typ ulohy
		Row workingRow = new Row();
		// Riadok pre odosielacie tlaidlo
		Row buttonRow = new Row();
		buttonRow.setStyleName("SubmitButtonRow");
		/*==========================PRIDVANIE KOMPONENTOV==========================*/
		// Riadok pre obalenie startField a startFieldButton
		startDateRow.add(startField);
		startDateRow.add(startDateButton);  
		// Riadok pre obalenie endField a endDateButton
		endDateRow.add(endField);
		endDateRow.add(endDateButton);
		// Riadok pre obalenie radiobutton pre prvy typ ulohy
		preparationRow.add(preparationLabel);
		preparationRow.add(preparationStateButton);
		// Riadok pre obalenie radiobutton pre druhy typ ulohy
		workingRow.add(workingLabel);
		workingRow.add(workingStateButton);
		// Riadok pre odosielacie tlaidlo
		buttonRow.add(submitButton);
		// Komponenty pridme do mrieky	
		// 1. Riadok
		grid.add(nameLabel);
		grid.add(nameField);
		// 2. Riadok
		grid.add(startLabel);
		grid.add(startDateRow);
		// 3. Riadok
		grid.add(endLabel);
		grid.add(endDateRow);
		// 4. Riadok
		grid.add(taskLabel);
		grid.add(taskArea);
		// 5. Riadok
		grid.add(preparationRow);
		grid.add(workingRow);
		// 6. Riadok
		grid.add(priorityLabel);
		grid.add(priorityField);
		// 7. Riadok
		grid.add(alarmLabel);
		grid.add(alarmField);
						
		// Do objektu SplitPane vlome najrpv riadok s tlaidlom a potom mrieku
		meetingPane.add(buttonRow);
		meetingPane.add(grid);
		
		return meetingPane;
	}

	/** 
	 * Metda vytvor a napln selectfield. Najprv je vytvoren a naplnen pole
	 * s dtami. Toto pole je nsledne predane v kontruktore. Nakoniec ete ozname 
	 * prv objekt v zozname. 
	 * */
	private SelectField createPriorityField() 
	{
		Object[] items = new Object[11];
		for(int i=0;i<=10;i++)
		{
			items[i] = ""+i ;
		}
		
		SelectField field = new SelectField(items);
		field.setSelectedIndex(0);
		return field;
	}
	
	/**
	 * Listener, pre tlaidl pre dtum. Najprv poda atribtu ID zistme, ktor tlaidlo bolo 
	 * stlaen. Poda toho predme prslun textov poe okno s kalendrikom.
	 */
	private ActionListener calendarListener = new ActionListener() 
	{
		public void actionPerformed(ActionEvent ae) 
		{
			Button button = (Button) ae.getSource();
			String buttonId = button.getId();
			TextField field;
			if(buttonId.equals(START_DATE_BUTTON_ID))
			{
				field = startField;
			} else {
				field = endField;
			}
			AppInstance.getActive().getDefaultWindow().getContent().add(new DateWindow(field));
		}
	};
	
	/** 
	 * Listener sli na prebratie dajov z formulrov. Tieto daje nsledne mu by uloen.
	 * */
	private ActionListener buttonListner = new ActionListener()
	{

		public void actionPerformed(ActionEvent ae) 
		{
			Button button = (Button)ae.getSource();
			String buttonId = button.getId();
			if(buttonId.equals(MEETING_TAB_BUTTON))
			{
				String subject = subjectField.getText();
				String place = placeField.getText();
				String start = startField.getText();
				String end = endField.getText();
				String note = notesArea.getText();
			} else if(buttonId.equals(TASK_TAB_BUTTON)) {
				String name = nameField.getText();
				String start = startField.getText();
				String end = endField.getText();
				boolean preparationState = preparationStateButton.isSelected();
				boolean workingstate = workingStateButton.isSelected();
				int selectedIndex = priorityField.getSelectedIndex();
				Object obj = priorityField.getSelectedItem();
				boolean alarmSelected = alarmField.isSelected();
			}
		}
	};
	
}
